from distutils.core import setup

setup(
    name = 'print_list2',
    version = '1.2.0',
    py_modules = ['print_list2'],
    author = 'jaejin',
    author_email = 'jaejin0me@gmail.com',
    url = '',
    description = 'a simple printer of nested lists',
)
